#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-web
version:              1.52.1
visibility:           public
id:                   hledger-web-1.52.1-31j64YL4Vnu8mctxTN84BY
key:                  hledger-web-1.52.1-31j64YL4Vnu8mctxTN84BY
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Web user interface for the hledger accounting system
description:
    A simple web user interface for the hledger accounting system,
    providing a more modern UI than the command-line or terminal interfaces.
    It can be used as a local single-user UI, or as a multi-user UI for
    viewing\/adding\/editing on the web.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance
abi:                  432afb75da30ee7aacc37d6f06d2802f
exposed:              True
exposed-modules:
    Hledger.Web Hledger.Web.App Hledger.Web.Application
    Hledger.Web.Handler.AddR Hledger.Web.Handler.EditR
    Hledger.Web.Handler.JournalR Hledger.Web.Handler.MiscR
    Hledger.Web.Handler.RegisterR Hledger.Web.Handler.UploadR
    Hledger.Web.Import Hledger.Web.Main Hledger.Web.Settings
    Hledger.Web.Settings.StaticFiles Hledger.Web.Test
    Hledger.Web.WebOptions Hledger.Web.Widget.AddForm
    Hledger.Web.Widget.Common

hidden-modules:       Paths_hledger_web
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-web-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger-web
hs-libraries:         HShledger-web-1.52.1-31j64YL4Vnu8mctxTN84BY
depends:
    Decimal-0.5.2-ATpEq7dgWLe6QoOidScxUv
    aeson-2.2.2.0-I4TBg1DJhLsFbcwgkuafNJ base-4.18.2.1
    base64-1.0-CaFzo57yDfy3C1ftFMeb7U
    blaze-html-0.9.2.0-C3tYv95GKuhLnKAx05hjcw
    blaze-markup-0.8.3.0-31LOlZqXeVaGGqnp712BTi bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Io2qVGlYpC0Ko64AoDztcG
    clientsession-0.9.3.0-AWeETf69hMkEgyQUN7QL8b
    cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    conduit-1.3.6.1-EcgUgvtEMLyH8F5dS2Qay5
    conduit-extra-1.3.8-Pkl5t82V3lFiXu05t8a32 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-D7xOqdBl5Y0CRCTPxKeT4r
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    githash-0.1.6.3-LesuwGyGVmUADQXx8bzkaD
    hjsmin-0.2.1-HcESGZkDlrVHjiToWnPlt0
    hledger-1.52.1-3RMiwlXc4R6LoKZPzShVtZ
    hledger-lib-1.52.1-1JwK9RESEhq269VD45heVu
    hspec-2.11.6-BbEEg2y8GOLI4Xv79thZsm
    http-client-0.7.19-D9XDbMj7HQLAGyouPpExP5
    http-conduit-2.3.9.1-4xpeFSGMYU5Jef4BWByQnK
    http-types-0.12.4-J4f9RYTa0ze5zkpv7SJ8lm
    megaparsec-9.7.0-GFwpasy74KM76q3sEXYwuE mtl-2.3.1
    network-3.1.4.0-3TdAlJZpcec7X0sHQ887x8
    safe-0.3.21-5GRmYTkULmq6icua5Lvt8V
    shakespeare-2.1.7.1-9Sa6AXiAeHfKPlWEgp63EK
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-HK3thdsDfAWHXS2uR0zDUL
    unordered-containers-0.2.20.1-9MqMq77Kwyw3AYghIevUCW
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    wai-3.2.4-AbeRAt4VbX71hUAZJ2jn1Q
    wai-cors-0.2.7-3qi2nP4IGOCIsCkhBCjwFT
    wai-extra-3.1.18-CmubiDBUBo5AkuQtSGjRU
    wai-handler-launch-3.0.3.1-1Sj90zO5yHbFThXwfkEIL7
    warp-3.4.0-BDJaJCcpYjEE7vdhVdOwwq
    yaml-0.11.11.2-LmJ3lQubKx2LZPMJyshbOQ
    yesod-1.6.2.1-GDGYO0uwNFlIckyLOwQ3ty
    yesod-core-1.6.28.0-tlKWDRW9Yr2LbDo2B8NQB
    yesod-form-1.7.9.2-K5tbetDRzIVETTO4YbrfYY
    yesod-static-1.6.1.2-76OHP7WopZfDCxojn15fWZ
    yesod-test-1.6.23-EQ9MB9dCIV336sBg5srwFn

haddock-interfaces:   /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html:         /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

